@@ -1,6 +1,6 @@
 package App::Sets::Sort;
 {
-  $App::Sets::Sort::VERSION = '0.973_04';
+  $App::Sets::Sort::VERSION = '0.973_05';
 }
 
 # ABSTRACT: sort handling
@@ -27,10 +27,9 @@ sub sort_filehandle {
    state $has_sort = ! $config->{internal_sort};
 
    if ($has_sort) {
-      if (open my $fh, '-|', 'sort', '-u', $filename) {
-         return $fh;
-      }
-      WARN "cannot use system sort, falling back to internal implementation";
+      my $fh;
+      eval { open $fh, '-|', 'sort', '-u', $filename } and return $fh;
+      WARN 'cannot use system sort, falling back to internal implementation';
       $has_sort = 0; # from now on, use internal sort
    }
 
@@ -144,7 +143,7 @@ App::Sets::Sort - sort handling
 
 =head1 VERSION
 
-version 0.973_04
+version 0.973_05
 
 =head1 AUTHOR
 
